%define major_version 1.2
%define minor_version 1
%define csprefix %{name}-%{major_version}

Name:           crystalspace
Version:        %{major_version}.%{minor_version}
Release:        6%{?dist}
Summary:        Crystal Space a free 3D engine
Group:          System Environment/Libraries
# most of crystalspace is LGPLv2+, but the sndsys class (and its plugins) and
# the ceguitest demo are GPLv2+. The snsdsys class being GLPv2+ effectively
# makes crystalspace completely GPLv2+. Also the following addons are GPLv2:
# the maya2spr utility, the scripts for exporting to crystalspace format from
# 3DS max and the movierecorder plugin.
License:        GPLv2+ and GPLv2
URL:            http://www.crystalspace3d.org/
Source0:        http://www.crystalspace3d.org/downloads/release/%{name}-src-%{version}.tar.bz2
Patch0:         crystalspace-1.2-cs-config.patch
Patch1:         crystalspace-1.2-ppc64.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  libpng-devel libjpeg-devel libmng-devel lcms-devel swig
BuildRequires:  libvorbis-devel alsa-lib-devel freetype-devel
BuildRequires:  cal3d-devel ode-devel cegui-devel libGLU-devel lib3ds-devel
BuildRequires:  python-devel freealut-devel mikmod-devel
BuildRequires:  libXxf86vm-devel SDL-devel wxGTK-devel libXaw-devel

%description
Crystal Space is a free (LGPL) and portable 3D SDK
written in C++.


%package utils
Summary:        Utilities for Crystal Space free 3D SDK
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description utils
Utilities for Crystal Space free 3D SDK.


%package demos
Summary:        Demos for Crystal Space free 3D SDK
Group:          Development/Libraries
Requires:       %{name}-utils = %{version}-%{release}

%description demos
Demos for Crystal Space free 3D SDK.


%package devel
Summary:        C++ headers and link libraries for Crystal Space free 3D SDK
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       libGL-devel cegui-devel zlib-devel

%description devel
Headers and link libraries needed for building
projects based upon the Crystal Space 3D SDK.


%package doc
Summary:        Documentation for Crystal Space free 3D SDK
Group:          Development/Libraries

%description doc
Documentation (manual and public API reference)
for Crystal Space free 3D SDK.


%prep
%setup -q -n %{name}-src-%{version}
%patch0 -p1 -z .cs-config
%patch1 -p1
sed -i 's/COMPILER.CFLAGS.debug += -DCS_DEBUG ;//' Jamrules
# work around mikmod not being linked to libdl as it should (bug 431745)
sed -i 's/-lmikmod/-lmikmod -ldl/g' configure
# stop configure from adding -L/usr/local/lib to cs-config (and the build)
sed -i 's|-d /usr/local/lib|-d /foobar|' configure

# some general cleanups (make rpmlint happy)
sed -i 's/\r//g' docs/history_1.2.txt
iconv -f ISO-8859-1 -t UTF8 docs/history.old > tmp
touch -r docs/history.old tmp
mv tmp docs/history.old
chmod -x plugins/sndsys/renderer/software/drivers/alsa/driver_alsa.*
chmod -x plugins/sndsys/utility/eventrecorder/eventrecorder.*
chmod -x plugins/sndsys/renderer/software/drivers/null/driver_null.*
chmod -x include/isndsys/ss_eventrecorder.h
chmod -x plugins/video/canvas/xwindow/xalert_xaw/makeform.c


%build
# Try to work around redhat bugzilla bug 432185
export CFLAGS="$RPM_OPT_FLAGS -fno-inline-small-functions"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-inline-small-functions"
# we don't want any FSCK-ing custom CFLAGS (die custom build tools like jam,
# die) so we force a debug build (and remove CS_DEBUG from the defines)
# --disable-meta-info-embedding as it conflicts with -debuginfo generation
# --without-python for ppc to work around rh bug 432185
%configure --enable-shared --enable-mode=debug --disable-separate-debug-info \
  --enable-cpu-specific-optimizations=no --disable-meta-info-embedding \
%ifarch ppc ppc64
  --without-python
%endif

make %{?_smp_mflags} all


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

# remove unneeded python dir from linkpath, as it causes a multilib conflict
sed -i 's| -L%{_libdir}/python2.5||' \
  $RPM_BUILD_ROOT%{_bindir}/cs-config-%{major_version}
 
# and do some more general cleanups
chmod +x $RPM_BUILD_ROOT%{_libdir}/lib%{name}*-%{major_version}.so
chmod +x $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/build/autoconf/config.*
chmod +x $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/build/autoconf/install-sh
chmod +x $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/build/jamtemplate/autogen.template
%ifnarch ppc ppc64
chmod +x $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/bindings/python/tutorial?.py
chmod +x $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/bindings/python/pyceguitest.py
%endif
rm -r $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/bindings/perl5
# put the bindings in %{_libdir} as they contain .so files
mv $RPM_BUILD_ROOT%{_datadir}/%{csprefix}/bindings \
  $RPM_BUILD_ROOT%{_libdir}/%{csprefix}


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%post utils
for map in castle flarge partsys terrain terrainf; do
  %{_bindir}/cslight -video=null $map 2>&1 > /dev/null || :
done


%files
%defattr(-,root,root,-)
%doc %dir %{_datadir}/doc/%{name}-%{version}
%doc %{_datadir}/doc/%{name}-%{version}/LICENSE
%doc %{_datadir}/doc/%{name}-%{version}/README
%doc %{_datadir}/doc/%{name}-%{version}/history*
%config(noreplace) %{_sysconfdir}/%{csprefix}
%exclude %{_sysconfdir}/%{csprefix}/autoexec.cfg
%exclude %{_sysconfdir}/%{csprefix}/csdemo.cfg
%exclude %{_sysconfdir}/%{csprefix}/g2dtest.cfg
%exclude %{_sysconfdir}/%{csprefix}/heightmapgen.cfg
%exclude %{_sysconfdir}/%{csprefix}/lighter.xml
%exclude %{_sysconfdir}/%{csprefix}/lighter2.cfg
%exclude %{_sysconfdir}/%{csprefix}/startme.cfg
%exclude %{_sysconfdir}/%{csprefix}/walktest.cfg
%exclude %{_sysconfdir}/%{csprefix}/waterdemo.cfg
%{_libdir}/*.so
%{_libdir}/%{csprefix}
%{_datadir}/%{csprefix}
%exclude %{_libdir}/%{csprefix}/bindings
%exclude %{_datadir}/%{csprefix}/conversion
%exclude %{_datadir}/%{csprefix}/build
%exclude %{_datadir}/%{csprefix}/data/startme.zip
%exclude %{_datadir}/%{csprefix}/data/ceguitest
%exclude %{_datadir}/%{csprefix}/data/maps

%files utils
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/%{csprefix}/autoexec.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/heightmapgen.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/lighter.xml
%config(noreplace) %{_sysconfdir}/%{csprefix}/lighter2.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/walktest.cfg
%{_bindir}/*
%exclude %{_bindir}/cs-config*
%exclude %{_bindir}/ceguitest*
%exclude %{_bindir}/csdemo*
%exclude %{_bindir}/startme*
%{_datadir}/%{csprefix}/data/maps
%{_datadir}/%{csprefix}/conversion

%files demos
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/%{csprefix}/csdemo.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/g2dtest.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/startme.cfg
%config(noreplace) %{_sysconfdir}/%{csprefix}/waterdemo.cfg
%{_bindir}/ceguitest*
%{_bindir}/csdemo*
%{_bindir}/startme*
%{_datadir}/%{csprefix}/data/startme.zip
%{_datadir}/%{csprefix}/data/ceguitest

%files doc
%defattr(-,root,root,-)
%doc %dir %{_datadir}/doc/%{name}-%{version}
%doc %{_datadir}/doc/%{name}-%{version}/html

%files devel
%defattr(-,root,root,-)
%{_bindir}/cs-config*
# (vk) Scripting related files are here for now
%{_libdir}/%{csprefix}/bindings
%{_datadir}/%{csprefix}/build
%{_includedir}/%{csprefix}


%changelog
* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 04 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.2.1-4
- Rebuild for Python 2.6

* Wed Dec  3 2008 Hans de Goede <hdegoede@redhat.com> 1.2.1-3
- Rebuild for new cegui

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.2.1-2
- Rebuild for Python 2.6

* Mon Sep 29 2008 Lubomir Rintel <lkundrak@v3.sk> 1.2.1-1
- Bump to next upstream release

* Mon Sep 29 2008 Lubomir Rintel <lkundrak@v3.sk> 1.2-8
- Rebuild for new libode

* Fri Jul 11 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-7
- Rebuild for new cegui

* Tue Jun 17 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-6
- Fix building on ppc64, patch from David Woodhouse

* Mon May 19 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-5
- Rebuild for new cegui
- Work around redhat bugzilla bug 432185 on ppc by disabling python on ppc

* Sun Feb 17 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-4
- More fixes from review (bz 432033):
  - Add Requires: cegui-devel and zlib-devel to -devel package
  - Add INSTALL="install -p" to make install flags
  - Change main package License to: GPLv2+ and GPLv2 and let all the sub-
    packages inherent this, for details see the comments and the discussion
    in the review (bz 432033)

* Thu Feb 14 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-3
- Fixes from review (bz 432033):
  - Silence -utils package %%post script
  - Fix docdir ownership
  - Fix multilib conflicts in cs-config-1.2
  - Add Requires: libGL-devel to -devel package
- Disable building on ppc until redhat bug 432185 gets resolved
- Move bindings completely to %%{_libdir} instead of only moving the .so files

* Wed Feb  6 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1.2-2
- Initial Fedora package based on cleaned up version of spec included with
  crystalspace

* Thu Aug 16 2007 Vincent Knecht <vknecht@users.sourceforge.net> 1.2-1
- Updated for 1.2 release.
- Added 'fullversion' variable for doc directory naming.

* Sat Jul 21 2007 Vincent Knecht <vknecht@users.sourceforge.net> 1.1-0.svn20070721.1
- Updated for AWS stuff removal and lighter2 addition.
- Updated for multiple install support (versioned directories and cs-config).

* Tue Oct 24 2006 Vincent Knecht <vknecht@users.sourceforge.net> 1.1-0.svn20061024.1
- Updated for SVN and new trunk version number.
- Disabled stripping even in optimize mode, it erases .crystalspace section.
- Disabled external debug info package generation.
- Added BuildRequires directives.

* Sun Mar 19 2006 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-0.cvs20060319.1
- Added shared lib option. Note that this option makes the package unusable as
  a SDK for now.

* Mon Oct 17 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-0.cvs20051016.1
- Added demos subpackage, no stripping for debug build and SMP friendly macros
  for make.

* Fri Sep 23 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-0.cvs20050924.1
- Added 'startme' stuff.

* Sun Apr 24 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-0.cvs20050424.1
- Removed csbumptest.cfg occurences.
- Changed release numbering scheme so one knows the date of tested snapshot.
- Put maps relighting in a for loop. Added terrain and terrainf to the list.
- Changed occurences of %%{name} to %%{csprefix} where value is not dependent
  upon package name.

* Fri Mar 25 2005 Frank Richter <resqu@gmx.ch> 0.99-11
- The CSWS library has been retired.

* Sun Feb 27 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-10
- Cleanup (using more wildcards, %%exclude and %%{_bindir}).

* Fri Feb 25 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-9
- Upgraded for new csplugincommon include directory.

* Wed Jan 05 2005 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-8
- Made a separate package for utilities.

* Mon Dec 13 2004 Eric Sunshine <sunshine@sunshineco.com> 0.99-7
- The old-renderer has been retired.

* Sun Nov 28 2004 Eric Sunshine <sunsihne@sunshineco.com> 0.99-6
- Crystal Space now has its own domain: crystalspace3d.org.
- New renderer is now default (configure with --enable-old-renderer for old).

* Mon Nov 22 2004 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-5
- Moved cslight invokations to post-install step.
- Changed cslight invokations to use null instead of null2d.

* Thu Nov 04 2004 Eric Sunshine <sunshine@sunshineco.com> 0.99-4
- Upgraded for new location of installed map files.
- Improved the package descriptions.

* Sat Aug 07 2004 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-3
- Upgraded for new headers installation directory.

* Fri Jul 09 2004 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-2
- Simplified and re-enabled levels relighting.

* Thu Jul 08 2004 Vincent Knecht <vknecht@users.sourceforge.net> 0.99-1
- Adaptation for CS PACKAGE_NAME change.
- Changed Group: to Development/C++
- Disabled levels relighting since lightmaps aren't written where expected.

* Sun Jul 04 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040704-1
- Specified datadir, libdir and sysconfig switches at configure step.
- Specified CS_CONFIGDIR in cslight commands.
- Re-enabled levels relighting when building NR.

* Mon Jun 28 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040628-1
- Added conditional build flags to enable debug, NR and perl plugin.
- Disabled relighting of levels when building NR. Crashes for me.

* Mon May 31 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040531-2
- Added %%files entries for .inc and .fun files in include/csutil/

* Tue May 11 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040511-1
- Prefixed source file name with URL.
- Building is done by the make emulation layer, which will automatically
  call system installed jam if present, or use CS provided jam.

* Sun May 9 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040509-1
- Building is done by jam provided with Crystal Space if not installed
- Specified null2d canvas for levels relighting
- Added %%{prefix}/include/ivaria/*.i to devel %%files section
- Removed reference to include/csappframe/ dir

* Sat Feb 28 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040228-1
- Added lightmaps cache computation for flarge and partsys

* Sat Feb 28 2004 Philip Wyett <philip@wyett.net>
- Removed reference to 'include/imesh/thing/ dir.

* Tue Feb 10 2004 Eric Sunshine <sunshine@users.sourceforge.net>
- Unification and clean up of package descriptions.

* Mon Feb 9 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040209-3
- Using /usr for %%{prefix}
- Fixed bogus doc package by using %%docdir instead of %%doc

* Fri Feb 7 2004 Vincent Knecht <vknecht@users.sourceforge.net> 20040207-1
- using jam to build and install
- Update %%files section according to latest cvs snapshot
- Use %%{prefix} instead of hardcoded /usr/local/crystal
- splitted %%files section in multiple packages ('main', -devel, -doc)

* Tue Jan 14 2003 Eric Sunshine <sunshine@users.sourceforge.net>
- Upgraded for new Autoconf project configuration used by Crystal Space.

* Tue Dec 24 2002 Che <newrpms.sunsite.dk>
- Some adaptions for latest cvs tarball

* Thu Nov 14 2002 Che <newrpms.sunsite.dk>
- Initial rpm release
